@@ -69,17 +69,18 @@ class HangupsDisconnected(Exception):
     """Raised when hangups is disconnected."""
 
 
-class ChatUI(object):
+class ChatUI:
     """User interface for hangups."""
 
     def __init__(self, refresh_token_path, keybindings, palette,
                  palette_colors, datetimefmt, notifier_,
-                 discreet_notifications, manual_login):
+                 discreet_notifications, manual_login, keep_emoticons):
         """Start the user interface."""
         self._keys = keybindings
         self._datetimefmt = datetimefmt
         self._notifier = notifier_
         self._discreet_notifications = discreet_notifications
+        self._keep_emoticons = keep_emoticons
 
         set_terminal_title('hangups')
 
@@ -201,7 +202,7 @@ class ChatUI(object):
             widget = ConversationWidget(
                 self._client, self._coroutine_queue,
                 self._conv_list.get(conv_id), set_title_cb, self._keys,
-                self._datetimefmt
+                self._datetimefmt, self._keep_emoticons
             )
             self._conv_widgets[conv_id] = widget
         return self._conv_widgets[conv_id]
@@ -716,6 +717,7 @@ class ConversationEventListWalker(urwid.ListWalker):
         self._conversation.on_watermark_notification.add_observer(
             self._on_watermark_notification
         )
+        super().__init__()
 
     def _handle_event(self, conv_event):
         """Handle updating and scrolling when a new event is added.
@@ -867,7 +869,7 @@ class ConversationWidget(WidgetBase):
     """Widget for interacting with a conversation."""
 
     def __init__(self, client, coroutine_queue, conversation, set_title_cb,
-                 keybindings, datetimefmt):
+                 keybindings, datetimefmt, keep_emoticons):
         self._client = client
         self._coroutine_queue = coroutine_queue
         self._conversation = conversation
@@ -876,6 +878,7 @@ class ConversationWidget(WidgetBase):
             self._on_watermark_notification
         )
         self._keys = keybindings
+        self._keep_emoticons = keep_emoticons
 
         self.title = ''
         self._set_title_cb = set_title_cb
@@ -933,11 +936,17 @@ class ConversationWidget(WidgetBase):
         elif text.startswith('/image') and len(text.split(' ')) == 2:
             # Temporary UI for testing image uploads
             filename = text.split(' ')[1]
-            image_file = open(filename, 'rb')
+            try:
+                image_file = open(filename, 'rb')
+            except FileNotFoundError:
+                message = 'Failed to find image {}'.format(filename)
+                self._status_widget.show_message(message)
+                return
             text = ''
         else:
             image_file = None
-        text = replace_emoticons(text)
+        if not self._keep_emoticons:
+            text = replace_emoticons(text)
         segments = hangups.ChatMessageSegment.from_str(text)
         self._coroutine_queue.put(
             self._handle_send_message(
@@ -1088,7 +1097,7 @@ def main():
     # Create a default empty config file if does not exist.
     dir_maker(user_config_path)
     if not os.path.isfile(user_config_path):
-        with open(user_config_path, 'a') as cfg:
+        with open(user_config_path, 'a', encoding="utf-8") as cfg:
             cfg.write("")
 
     parser = configargparse.ArgumentParser(
@@ -1115,6 +1124,8 @@ def main():
     general_group.add('--manual-login', action='store_true',
                       help='enable manual login method')
     general_group.add('--log', default=default_log_path, help='log file path')
+    general_group.add('--keep-emoticons', action='store_true',
+                      help='do not replace emoticons with corresponding emoji')
     key_group = parser.add_argument_group('Keybindings')
     key_group.add('--key-next-tab', default='ctrl d',
                   help='keybinding for next tab')
@@ -1204,7 +1215,7 @@ def main():
         ChatUI(
             args.token_path, keybindings, col_scheme, palette_colors,
             datetimefmt, notifier_, args.discreet_notifications,
-            args.manual_login
+            args.manual_login, args.keep_emoticons
         )
     except KeyboardInterrupt:
         sys.exit('Caught KeyboardInterrupt, exiting abnormally')
